-- coding: utf-8 --

# anywsgi-py

quick and dirty use any available WSGI server for running from command line

  * https://pypi.org/project/anywsgi/
  * https://github.com/clach04/anywsgi-py

## Getting Started

### Regular install

    pip install anywsgi

### Without a source code checkout

Picking up the latest version

    pip uninstall anywsgi; python -m pip install --upgrade git+https://github.com/clach04/anywsgi-py.git

### From a source code checkout

    # pip uninstall anywsgi
    # python -m pip install -r requirements.txt
    # TODO requirements_optional.txt
    python -m pip install -e .
